@@ -46,8 +46,8 @@ import os
 PROG_NAME = 'lsr'
 
 # version numbers
-PROG_VERSION = '0.5.1'
-PROG_DATE = 'Fri Apr 20 13:16:27 UTC 2007'
+PROG_VERSION = '0.5.2'
+PROG_DATE = 'Mon May 14 22:33:09 UTC 2007'
 
 # name, version, copyright and license notice to print on startup
 NAME = 'Linux Screen Reader'
@@ -79,8 +79,10 @@ def initUserPath(pth):
   @rtype: boolean
   '''
   try:
-    # ensure we're creating in the user's home dir under the same uid
-    if os.stat(os.environ['HOME']).st_uid == os.getuid():
+    # ensure we're creating in the user's home dir under the same gid
+    # uid doesn't work for some special user homes (e.g. gdm) created by
+    # the root user
+    if os.stat(os.environ['HOME']).st_gid == os.getgid():
       os.makedirs(pth)
       return True
   except OSError:
