@@ -4,7 +4,7 @@ Defines an L{AEEvent} indicating that the caret has moved.
 @author: Pete Brunet
 @author: Larry Weiss
 @organization: IBM Corporation
-@copyright: Copyright (c) 2005, 2006 IBM Corporation
+@copyright: Copyright (c) 2005, 2007 IBM Corporation
 @license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made 
@@ -13,14 +13,15 @@ this distribution, and is available at
 U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 
-import Base, Constants
+import Base
+from AEConstants import LAYER_FOCUS
 
 class CaretChange(Base.AccessEngineEvent):
   '''
   Event that fires when the caret moves in an accessible.
   
   This class registers its name and whether it should be monitored by default in
-  an L{AEMonitor} using the L{Constants.registerEventType} function
+  an L{AEMonitor} using the L{Base.registerEventType} function
   when this module is first imported. The L{AEMonitor} can use this
   information to build its menus.
   
@@ -33,7 +34,7 @@ class CaretChange(Base.AccessEngineEvent):
     (the default) when event is for caret movement only
   @type added: boolean
   '''
-  Constants.registerEventType('CaretChange', False)
+  Base.registerEventType('CaretChange', False)
   
   def __init__(self, por, text, text_offset, added=None, **kwargs):
     '''
@@ -76,7 +77,7 @@ class CaretChange(Base.AccessEngineEvent):
     return '%s:\n\tPOR: %s\n\ttext: %s\n\toffset: %d\n\taction: %s' % \
            (name, self.por, self.text, self.text_offset, action)
   
-  def execute(self, tier_manager, **kwargs):
+  def execute(self, tier_manager, view_manager, **kwargs):
     '''
     Contacts the L{TierManager} so it can manage the caret change event.
     
@@ -84,11 +85,15 @@ class CaretChange(Base.AccessEngineEvent):
     @type tier_manager: L{TierManager}
     @param kwargs: Packed references to other managers not of interest here
     @type kwargs: dictionary
-    @return: Always True to indicate the event executed properly
+    @return: True if there is an active view, False if not to delay execution 
+      of this event until there is
     @rtype: boolean
     '''
-    tier_manager.manageEvent(self)
-    return True
+    if view_manager.getAEView() is None and self.layer == LAYER_FOCUS:
+      return False
+    else:
+      tier_manager.manageEvent(self)
+      return True
 
   def getDataForTask(self):
     '''
