@@ -5,7 +5,7 @@ deleted, or has been reordered.
 @author: Brett Clippingdale
 @author: Peter Parente
 @organization: IBM Corporation
-@copyright: Copyright (c) 2005, 2006 IBM Corporation
+@copyright: Copyright (c) 2005, 2007 IBM Corporation
 @license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made 
@@ -14,14 +14,14 @@ this distribution, and is available at
 U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 
-import Base, Constants
+import Base
 
 class TableChange(Base.AccessEngineEvent):
   '''
   Event that fires when the rows and columns in a table change.
   
   This class registers its name and whether it should be monitored by default in
-  an L{AEMonitor} using the L{Constants.registerEventType} function
+  an L{AEMonitor} using the L{Base.registerEventType} function
   when this module is first imported. The L{AEMonitor} can use this
   information to build its menus.
 
@@ -36,7 +36,7 @@ class TableChange(Base.AccessEngineEvent):
   @ivar last_child_por: Point of regard of last added/removed/moved child
   @type last_child_por: L{POR}
   '''
-  Constants.registerEventType('TableChange', False)
+  Base.registerEventType('TableChange', False)
   def __init__(self, por, is_row, added, first_child_por, last_child_por, 
                **kwargs):
     '''
