@@ -150,9 +150,6 @@ class Audio(Base.AEOutput):
       - expanded numbers
       - spelling format
     
-    @todo: PP: add support for all other speech parsing features (see old
-      LSRSettings module)
-    
     @param text: Text to be parsed
     @type text: string
     @param style: Style object defining how the text should be parsed
