@@ -290,43 +290,24 @@ class DefaultAccActionAdapter(PORAdapter):
       return text_area.removeSelection(n)
 
   @pyLinAcc.errorToLookupError
-  def doMouseClickAtPOR(self, mouseevent):
+  def doMouseAction(self, event):
     '''
-    Performs a mouse event on the center of a given point of regard.  If the
-    accessible has a role of text, then set cursor at given location in por
+    Performs a mouse event on the center of a given point of regard.
     
-    @param mouseevent: mouse event to perform
-    @type mouseevent: integer (EVENT_SYNTHMOUSE*)
-    @return: Indicator of whether the acc was clicked or not
+    @param event: Mouse event to perform
+    @type event: integer (EVENT_SYNTHMOUSE*)
+    @return: Indicator of whether the event succeded or not
     @raise LookupError: When the accessible object is dead
     '''
-    acc = self.accessible
-    try:
-      itext = Interfaces.IText(acc)
-      if self.char_offset is not None and self.item_offset is not None:
-        # setCaretOffset returns boolean
-        if not itext.setCaretOffset(self.char_offset+self.item_offset):
-          self._doMouseClickAtCenter(mouseevent)
-      else:
-        self._doMouseClickAtCenter(mouseevent)
-    except LookupError:
-      self._doMouseClickAtCenter(mouseevent)
-    return True
-      
-  def _doMouseClickAtCenter(self, mouseevent):
-    '''
-    Performs a mouse event on the center of the given accessible. Internal
-    method used by L{doMouseClickAtPOR}, not part of the interface.
-    
-    @param mouseevent: Mouse event to perform
-    @type mouseevent: integer (EVENT_SYNTHMOUSE*)
-    '''
- #   vpt_x, vpt_y = IAccessibleInfo(self.subject).getAccVisualPoint()getAccPosition
     ai = IAccessibleInfo(self.subject)
     vpt_x, vpt_y = ai.getAccPosition()
     width, height = ai.getAccVisualExtents()
     devcont = pyLinAcc.Registry.getDeviceEventController()
-    devcont.generateMouseEvent(vpt_x + width*.5, vpt_y+ height*.5, mouseevent)
+    devcont.generateMouseEvent(vpt_x + width*.5, vpt_y+ height*.5, 
+                               event)
+    # we don't get notification of whether it succeeded or failed from AT-SPI,
+    # always assume success
+    return True
   
   @pyLinAcc.errorToLookupError
   def setAccFocus(self):
