@@ -217,10 +217,16 @@ class DefaultEventHandlerAdapter(Adapter):
           # abort immediately if the accessible has state defunct or if it has 
           # a redundant object role
           return
+
         # make a first guess as to whether the object is focused or not
-        focused = (DefaultEventHandlerAdapter.last_focus == event.source or 
-                   #ss.contains(Constants.STATE_FOCUSED) or
-                   ss.contains(Constants.STATE_ACTIVE))
+        # NOTE: fixed focus layer bug where events from unfocused controls 
+        # came through as being from the focus; testing against last known 
+        # focused control now, not just states except in case where no focus
+        # event has been received yet
+        lf = DefaultEventHandlerAdapter.last_focus
+        focused = (lf == event.source or 
+                   ss.contains(Constants.STATE_ACTIVE) or
+                   (ss.contains(Constants.STATE_FOCUSED) and lf is None))
       except AttributeError:
         # abort immediately if the CORBA object is dead
         return
@@ -250,7 +256,6 @@ class DefaultEventHandlerAdapter(Adapter):
     if events: 
       if method == self._handleFocusEvent:
         # synthesize focus lost events
-        lf = DefaultEventHandlerAdapter.last_focus
         if lf is not None:
           lost_events = self._handleUnfocusEvent(lf)
           if lost_events: collector(*lost_events)
