@@ -833,3 +833,25 @@ class DefaultAccInfoAdapter(PORAdapter):
     '''
     parent = IAccessibleNav(self.subject).getParentAcc()
     return IAccessibleInfo(parent).allowsAccEmbeds()
+  
+  def getAccURI(self, index):
+    '''
+    Obtain a resource locator ('URI') string which can be used to access the 
+    content to which this link "points" or is connected.
+    
+    @return: URI string
+    @rtype: string
+    @raise LookupError: When the accessible object is invalid
+    '''
+    return Interfaces.IHyperlink(self.subject).getURI(index)
+  
+  def getAccAnchorCount(self):
+    ''' 
+    Obtain he number of separate anchors associated with this accessible.
+    
+    @return: Number of anchors
+    @rtype: integer
+    @raise LookupError: When the accessible object is invalid
+    '''
+    return Interfaces.IHyperlink(self.subject).nAnchors
+  
\ No newline at end of file
