@@ -10,16 +10,12 @@ All rights reserved. This program and the accompanying materials are made
 available under the terms of the BSD license which accompanies
 this distribution, and is available at
 U{http://www.opensource.org/licenses/bsd-license.php}
-
-Current revision $Revision: 560 $
-Latest change by $Author: parente $ on $Date: 2007-02-16 16:44:37 -0500 (Fri, 16 Feb 2007) $
 '''
 import AEOutput
 from i18n import _
 from AEConstants import CMD_GOTO, CMD_GET_ROI
 from gtk.gdk import Display, get_display
 import ORBit, bonobo
-import pdb
 
 __uie__ = dict(kind='device')
 
@@ -71,7 +67,8 @@ class GnomeMagStyle(AEOutput.Style):
   '''
   def init(self, device):
     self.newBool('FullScreen', False, _('Full screen'),
-       _('Magnify in full screen mode, this only affects magnifiers that are in a seperate screen.'))
+       _('Magnify in full screen mode, this only affects magnifiers that are '
+         'in a seperate screen.'))
 
     self.newRange('Zoom', 2, _('Zoom Factor'), 1, 13, 1,
        _('Change the magnification zoom factor.'))
@@ -162,7 +159,6 @@ class GnomeMagStyle(AEOutput.Style):
 
     return g
 
-
 class GnomeMagDevice(AEOutput.AEOutput):
   '''
   A Gnome Magnifier.
@@ -350,10 +346,10 @@ class GnomeMagDevice(AEOutput.AEOutput):
     @param roi_tuple: Region of interest in x,y,w,h
     @type roi_tuple: 4-tuple of integer
     '''
-    self._roi = GNOME.Magnifier.RectBounds (*roi_tuple)
+    self._roi = GNOME.Magnifier.RectBounds(*roi_tuple)
     try:
       zoom.setROI(self._roi)
-    except:
+    except Exception:
       pass
 
   def _getPos(self, zoom):
@@ -367,7 +363,7 @@ class GnomeMagDevice(AEOutput.AEOutput):
     '''
     try:
       roi = zoom.getROI()
-    except:
+    except Exception:
       return None
     x_zoom, y_zoom = self.zoom.getMagFactor()
     x,y,w,h = self.zoom_pb_proxy['viewport']
@@ -390,7 +386,8 @@ class GnomeMagDevice(AEOutput.AEOutput):
     '''
     name = setting.name
     value = setting.value
-    if name[:-1] == 'TargetDisplay' or (name == 'FullScreen' and not style.FullScreen):
+    if (name[:-1] == 'TargetDisplay' or
+        (name == 'FullScreen' and not style.FullScreen)):
       self.mag_pb_proxy['target-display-bounds'] = (style.TargetDisplayX,
                                                     style.TargetDisplayY,
                                                     style.TargetDisplayW,
@@ -402,7 +399,11 @@ class GnomeMagDevice(AEOutput.AEOutput):
     elif name == 'FullScreen' and value:
       self._setFullScreen()
     elif name == 'Zoom':
+      # store original coordinates
+      roi = self._getPos(self.zoom)
       self.zoom.setMagFactor(value, value)
+      # correct for new coordinates
+      self._setPos(self.zoom, roi)
 
     if self.property_trans_mag.has_key(name):
       self.mag_pb_proxy[self.property_trans_mag[name]] = value
