@@ -84,9 +84,6 @@ def confirmRemove(name):
   Confirms deletion actions from the command prompt. Looks for a press of 'y'
   to indicate confirmation.
   
-  @todo: PP: what's best practice for these types of messages with i18n? i'm
-    guessing you don't want to translate since then you can't use utils like
-    'yes' from the command line
   @param name: Name of the "thing" being removed
   @type name: string
   @return: Confirm (True) or cancel (False)?
@@ -372,10 +369,6 @@ def run(options):
   '''
   Runs the screen reader.
   
-  @todo: We modify the GTK_MODULES environment variable here instead of using
-    the gtk init program call in modules that define gtk GUIs. We only want to
-    initialize accessibility once and we don't have to have a hard pygtk 
-    dependency here.
   @param options: Options seen on the command line
   @type options: optparse.Values
   @return: Description of the action
