@@ -13,7 +13,7 @@ the construction of gtk GUIs.
 
 @author: Peter Parente
 @organization: IBM Corporation
-@copyright: Copyright (c) 2005, 2006 IBM Corporation
+@copyright: Copyright (c) 2005, 2007 IBM Corporation
 @license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made 
@@ -105,7 +105,7 @@ class GTKEventDialog(AEMonitor.AEMonitor):
     # create one text buffer, two views
     self.text_buffer = gtk.TextBuffer()
     self.text_view = gtk.TextView(self.text_buffer)
-    self.text_view.set_pixels_below_lines(2)
+    self.text_view.set_pixels_below_lines(1)
     self.text_view.set_wrap_mode(gtk.WRAP_WORD)
     self.text_view.set_editable(False)
         
@@ -207,6 +207,11 @@ class GTKEventDialog(AEMonitor.AEMonitor):
       if name in self.getEventDefaults():
         i.set_active(True)
       display_menu.append(i)
+    # add additional menu items if needed 
+    try:
+      self._addViewMenuItems(display_menu)
+    except NotImplementedError:
+      pass
     return display_menu
 
   def _onSaveLog(self, widget):
@@ -295,7 +300,7 @@ class GTKEventDialog(AEMonitor.AEMonitor):
     '''
     return self.logging and event_name in self.shown
       
-  def _queueText(self, text):
+  def _queueText(self, text, tags=None):
     '''
     Queues text for later display in the L{text_view} when the L{window} does
     not have the focus and when the L{timer} fires.
@@ -303,7 +308,7 @@ class GTKEventDialog(AEMonitor.AEMonitor):
     @param text: Text to buffer and display
     @type text: string
     '''
-    self.queue.put_nowait(text)
+    self.queue.put_nowait((text,tags))
     
   def _onPumpQueue(self):
     '''
@@ -323,17 +328,39 @@ class GTKEventDialog(AEMonitor.AEMonitor):
     while count < PUMP_MAX and not self.window.is_active():
       try:
         # get the text to buffer
-        text = self.queue.get_nowait()
+        text,tags = self.queue.get_nowait()
         count += 1
       except Queue.Empty:
         break
       # buffer the text
       end = self.text_buffer.get_end_iter()
-      self.text_buffer.insert(end, text)
+      if tags is not None:
+        self.text_buffer.insert_with_tags_by_name(end, text, *tags)
+      else:
+        self.text_buffer.insert(end, text)
     if self.scroll and not self.window.is_active():
       # scroll to the bottom
       self.text_view.scroll_to_iter(self.text_buffer.get_end_iter(), 0.0)
       self.scroll = False
     if count:
       self.scroll = True
-    return True
\ No newline at end of file
+    return True
+    
+  def _addViewMenuItems(self, menu):
+    raise NotImplementedError
+  
+  def _insert_one_tag_into_buffer(self, name, params):
+    '''
+    Adds one named style tag into the L{GtkTextBuffer} tag table. These 
+    tags can then be used to add style to text that is queued in L{_queueText}.
+    
+    @param name: Tag name of this style
+    @type name: string
+    @param params: dictionary of key, value pairs that represent a style.
+    @type params: dictionary
+    '''
+    tag = gtk.TextTag(name)
+    for key, value in params.iteritems():
+      tag.set_property(key, value)
+    table = self.text_buffer.get_tag_table()
+    table.add(tag)
\ No newline at end of file
