@@ -271,7 +271,7 @@ class HandleLineEnd(Task.InputTask):
     if self.perk.getState().MoveCaret:
       # HandleCaretChange.update() will update current_text
       eol_por = self.getEndOfHardLine()
-      self.clickPOR(EVENT_SYNTHMOUSE_B1C, eol_por)
+      self.leftClickPOR(eol_por)
     else:
       # otherwise just set current_text for new por location
       self.task_por.char_offset = len(self.getItemText())
@@ -292,7 +292,7 @@ class HandleHome(Task.InputTask):
     # move caret if desired. 
     if self.perk.getState().MoveCaret:
       # HandleCaretChange.update() will update current_text
-      self.clickPOR(EVENT_SYNTHMOUSE_B1C, self.task_por)
+      self.leftClickPOR(self.task_por)
     else:
       # otherwise just set current_text for new por location
       self.perk.current_text = self.getItemText()
@@ -311,7 +311,7 @@ class HandleLineBegin(Task.InputTask):
     # move caret if desired. 
     if self.perk.getState().MoveCaret:
       # HandleCaretChange.update() will update current_text
-      self.clickPOR(EVENT_SYNTHMOUSE_B1C, self.task_por)
+      self.leftClickPOR(self.task_por)
     else:
       # otherwise just set current_text for new por location
       self.perk.current_text = self.getItemText()
@@ -342,7 +342,7 @@ class HandleTouchCursor(Task.InputTask):
       
     # adjust current por and send touch cursor 
     self.task_por.char_offset = newoffset
-    self.clickPOR(EVENT_SYNTHMOUSE_B1C, self.task_por)
+    self.leftClickPOR(self.task_por)
     
 class HandleScrollForward(Task.InputTask):
   '''
