@@ -3,7 +3,7 @@ Defines a L{Task} to execute when a timed interval passes.
 
 @author: Peter Parente
 @organization: IBM Corporation
-@copyright: Copyright (c) 2006 IBM Corporation
+@copyright: Copyright (c) 2005, 2007 IBM Corporation
 @license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made 
@@ -11,7 +11,7 @@ available under the terms of the BSD license which accompanies
 this distribution, and is available at
 U{http://www.opensource.org/licenses/bsd-license.php}
 '''
-import Base, Constants
+import Base
 
 class TimerTask(Base.Task):
   '''
@@ -20,20 +20,22 @@ class TimerTask(Base.Task):
   time will be honored.
 
   This class registers its name and whether it should be monitored by default
-  in an L{AEMonitor} using the L{Constants.registerTaskType}
+  in an L{AEMonitor} using the L{Base.registerTaskType}
   function when this module is first imported. The L{AEMonitor}
   can use this information to build its menus.  
   
   @ivar interval: Interval for the timer in seconds
   @type interval: integer
   '''
-  Constants.registerTaskType('TimerTask', False)
+  Base.registerTaskType('TimerTask', False)
   
-  def __init__(self, interval, ident=None):
+  def __init__(self, ident, interval):
     '''
     Stores the desired interval.
     
-    @param interval: Interval for the timer in seconds
+    @note: Changed from second to millisecond resolution
+    
+    @param interval: Interval for the timer in milliseconds
     @type interval: integer
     @param ident: Programmatic identifier
     @type ident: string
@@ -55,8 +57,7 @@ class TimerTask(Base.Task):
     
     @param interval: Interval in seconds on which the timer fires
     @type interval: integer
-    @param layer: Layer on which the event occurred, one of 
-      L{Task.LAYER_FOCUS}, L{Task.LAYER_TIER}, or L{Task.LAYER_BACKGROUND}
+    @param layer: Layer on which the event occurred
     @type layer: integer
     '''
     pass
