@@ -97,18 +97,29 @@ class TaskTools(object):
     @rtype: boolean
     '''
     if self.tools_initialized:
+      # don't reinitialize if we already are initialized
       return False
+    
     # store a reference to the AccessEngine and owning Tier
     self.acc_eng = ae
     self.tier = tier
+    
     # store the perk, which may be this object itself
     if perk is None:
       self.perk = self
     else:
       self.perk = perk
+      
     # get all manager references from AccessEngine very quickly
     self.acc_eng.loanManagers(self)
+    
+    # get all state objects
+    self.lsr_state = self.tier_man.getState()
+    self.perk_state = self.perk.getState()
+    
+    # indicate we're initialized now
     self.tools_initialized = True
+    
     return True
 
   def init(self):
@@ -124,18 +135,21 @@ class TaskTools(object):
     state information. Intended to be called after L{close}.
     '''
     if not self.tools_initialized:
+      # don't re-uninitialize
       return
+    # toss references to owning Perk and Tier
     self.tier = None
     self.perk = None
+    # throw away manager and access engine refs
     self.acc_eng.unloanManagers(self)
     self.acc_eng = None
-    # important! throw away this weak reference else the callback keeps this
-    # object alive
+    # IMPORTANT: throw away weak ref to deviceelse the callback keeps it alive
     self.def_out = None
-    self.tools_initialized = False
     # throw away references to state
     self.lsr_state = None
     self.perk_state = None
+    # inidicate we're not initialized anymore
+    self.tools_initialized = False
 
   def close(self):
     '''
@@ -158,10 +172,6 @@ class TaskTools(object):
     if not self.tools_initialized:
       # don't do anything if the tools aren't initialized
       return False
-
-    # get all state objects
-    self.lsr_state = self.tier_man.getState()
-    self.perk_state = self.perk.getState()
     
     # reset the auto pointer flag to True
     self.tools_auto_pointer = True
@@ -191,15 +201,8 @@ class TaskTools(object):
     if (self.perk is not self and # never store POR from Perk objects
         self.tools_initialized and # only store if initialized
         self.tools_auto_pointer and # only store if auto pointer
-        AEConstants.LAYER_FOCUS == self.layer and # only store if focus layer
-        self.tier.getAutoPointer()): # only store if in correct mode
+        AEConstants.LAYER_FOCUS == self.layer): # only store if focus layer
       self.tier.setPointer(self.task_por)
-    # PP: removed these because recursive nature of Tasks can 
-    # postExecute a Perk that is still executing and it will lose its state
-    # references (yikes)
-    #self.lsr_state = None
-    #self.perk_state = None
-    #self.def_out = None
 
   def _changeDefaultOutput(self, ref=None):
     '''
