@@ -121,24 +121,6 @@ class Tier(object):
     @type por: L{POR}
     '''
     self.pointer_por = por
-    
-  def getAutoPointer(self):
-    '''
-    Gets the auto pointer mode for this L{Tier}.
-    
-    @return: Current pointer mode.
-    @rtype: boolean
-    '''
-    return self.auto_pointer
-  
-  def setAutoPointer(self, mode):
-    '''
-    Sets the auto pointer mode for this L{Tier}.
-    
-    @param mode: Mode to set.
-    @type mode: boolean
-    '''
-    self.auto_pointer = mode
 
   def getFocus(self):
     '''
@@ -596,10 +578,7 @@ class Tier(object):
     '''
     try:
       # grab POR from any focus type event
-      if self.auto_pointer:
-        self.focus_por = event.getFocusPOR()
-      else:
-        self.focus_por = self.getPointer()
+      self.focus_por = event.getFocusPOR()
     except AttributeError:
       pass
     
