@@ -112,10 +112,14 @@ class ViewManager(object):
     that application, creates a L{Tier} for the application and loads all of
     its L{Perk}s. If the L{Tier} is created, this method sends
     L{AEEvent.ViewChange} messages to the L{Tier} with a flag of
-    L{AEConstants.EVENT_VIEW_STARTUP} such that L{Perk}s in the L{Tier}
+    L{AEConstants.Event.EVENT_VIEW_STARTUP} such that L{Perk}s in the L{Tier}
     may initialize themselves and begin any desired background processes.
     '''
-    d = pyLinAcc.Registry.getDesktop(0)
+    try:
+      d = pyLinAcc.Registry.getDesktop(0)
+    except Exception:
+      # just stop if we get an error right away
+      return
     ai = IAccessibleInfo(POR(d))
     an = IAccessibleNav(POR(d))
     events = []
@@ -264,7 +268,11 @@ class ViewManager(object):
     @return: True to continue receiving notifications
     @rtype: boolean
     '''
-    d = pyLinAcc.Registry.getDesktop(0)
+    try:
+      d = pyLinAcc.Registry.getDesktop(0)
+    except Exception:
+      # stop if we get an error immediately
+      return
     ai = IAccessibleInfo(POR(d))
     an = IAccessibleNav(POR(d))
     aids = []
